@@ -32,8 +32,9 @@ Usage::
     validate_policy_paginator: ValidatePolicyPaginator = client.get_paginator("validate_policy")
     ```
 """
-from typing import Dict, Iterator
+from typing import Dict, Generic, Iterator, TypeVar
 
+from botocore.paginate import PageIterator
 from botocore.paginate import Paginator as Boto3Paginator
 
 from .literals import LocaleType, PolicyTypeType, ResourceTypeType, TypeType
@@ -63,9 +64,19 @@ __all__ = (
 )
 
 
+_ItemTypeDef = TypeVar("_ItemTypeDef")
+
+
+class _PageIterator(Generic[_ItemTypeDef], PageIterator):
+    def __iter__(self) -> Iterator[_ItemTypeDef]:
+        """
+        Proxy method to specify iterator item type.
+        """
+
+
 class ListAccessPreviewFindingsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.29/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviewFindings)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.33/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviewFindings)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listaccesspreviewfindingspaginator)
     """
 
@@ -76,31 +87,31 @@ class ListAccessPreviewFindingsPaginator(Boto3Paginator):
         analyzerArn: str,
         filter: Dict[str, "CriterionTypeDef"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListAccessPreviewFindingsResponseTypeDef]:
+    ) -> _PageIterator[ListAccessPreviewFindingsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.29/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviewFindings.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.33/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviewFindings.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listaccesspreviewfindingspaginator)
         """
 
 
 class ListAccessPreviewsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.29/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviews)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.33/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviews)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listaccesspreviewspaginator)
     """
 
     def paginate(
         self, *, analyzerArn: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListAccessPreviewsResponseTypeDef]:
+    ) -> _PageIterator[ListAccessPreviewsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.29/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviews.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.33/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviews.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listaccesspreviewspaginator)
         """
 
 
 class ListAnalyzedResourcesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.29/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzedResources)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.33/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzedResources)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listanalyzedresourcespaginator)
     """
 
@@ -110,46 +121,46 @@ class ListAnalyzedResourcesPaginator(Boto3Paginator):
         analyzerArn: str,
         resourceType: ResourceTypeType = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListAnalyzedResourcesResponseTypeDef]:
+    ) -> _PageIterator[ListAnalyzedResourcesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.29/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzedResources.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.33/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzedResources.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listanalyzedresourcespaginator)
         """
 
 
 class ListAnalyzersPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.29/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzers)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.33/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzers)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listanalyzerspaginator)
     """
 
     def paginate(
         self, *, type: TypeType = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListAnalyzersResponseTypeDef]:
+    ) -> _PageIterator[ListAnalyzersResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.29/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzers.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.33/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzers.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listanalyzerspaginator)
         """
 
 
 class ListArchiveRulesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.29/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListArchiveRules)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.33/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListArchiveRules)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listarchiverulespaginator)
     """
 
     def paginate(
         self, *, analyzerName: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListArchiveRulesResponseTypeDef]:
+    ) -> _PageIterator[ListArchiveRulesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.29/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListArchiveRules.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.33/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListArchiveRules.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listarchiverulespaginator)
         """
 
 
 class ListFindingsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.29/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListFindings)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.33/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListFindings)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listfindingspaginator)
     """
 
@@ -160,31 +171,31 @@ class ListFindingsPaginator(Boto3Paginator):
         filter: Dict[str, "CriterionTypeDef"] = None,
         sort: "SortCriteriaTypeDef" = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListFindingsResponseTypeDef]:
+    ) -> _PageIterator[ListFindingsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.29/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListFindings.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.33/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListFindings.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listfindingspaginator)
         """
 
 
 class ListPolicyGenerationsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.29/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListPolicyGenerations)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.33/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListPolicyGenerations)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listpolicygenerationspaginator)
     """
 
     def paginate(
         self, *, principalArn: str = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListPolicyGenerationsResponseTypeDef]:
+    ) -> _PageIterator[ListPolicyGenerationsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.29/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListPolicyGenerations.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.33/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListPolicyGenerations.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#listpolicygenerationspaginator)
         """
 
 
 class ValidatePolicyPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.29/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ValidatePolicy)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.33/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ValidatePolicy)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#validatepolicypaginator)
     """
 
@@ -195,8 +206,8 @@ class ValidatePolicyPaginator(Boto3Paginator):
         policyType: PolicyTypeType,
         locale: LocaleType = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ValidatePolicyResponseTypeDef]:
+    ) -> _PageIterator[ValidatePolicyResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.29/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ValidatePolicy.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.33/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ValidatePolicy.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators.html#validatepolicypaginator)
         """
